@@ -4,10 +4,11 @@ from district42 import GenericSchema
 from district42.types import Schema
 
 from ._substitutor import Substitutor
+from ._validator import SubstitutorValidator
 from ._version import version
 
 __version__ = version
-__all__ = ("substitute", "Substitutor",)
+__all__ = ("substitute", "Substitutor", "SubstitutorValidator",)
 
 _substitutor = Substitutor()
 
